#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Core.Networks;
using HeuristicLab.MainForm;
using System;
using System.Windows.Forms;

namespace HeuristicLab.Operators.Views {
  [View("HookOperator View")]
  [Content(typeof(HookOperator), true)]
  [Content(typeof(IHookOperator), false)]
  public partial class HookOperatorView : OperatorView {
    public new IHookOperator Content {
      get { return (IHookOperator)base.Content; }
      set { base.Content = value; }
    }

    public HookOperatorView() {
      InitializeComponent();
      errorProvider.SetIconAlignment(portView, ErrorIconAlignment.MiddleRight);
      errorProvider.SetIconPadding(portView, 2);
    }

    protected override void DeregisterContentEvents() {
      Content.PortChanged -= Content_PortChanged;
      base.DeregisterContentEvents();
    }
    protected override void RegisterContentEvents() {
      base.RegisterContentEvents();
      Content.PortChanged += Content_PortChanged;
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
      portView.Content = Content == null ? null : Content.Port;
      parameterCollectionView.Content = Content == null ? null : Content.Parameters;
    }

    protected override void SetEnabledStateOfControls() {
      base.SetEnabledStateOfControls();
      portGroupBox.Enabled = Content != null && !ReadOnly && !Locked;
      clearPortButton.Enabled = Content != null && Content.Port != null && !ReadOnly && !Locked;
    }

    protected virtual void Content_PortChanged(object sender, EventArgs e) {
      if (InvokeRequired)
        Invoke(new EventHandler(Content_PortChanged), sender, e);
      else {
        clearPortButton.Enabled = Content.Port != null && !ReadOnly && !Locked;
        portView.Content = Content.Port;
      }
    }

    protected virtual void clearPortButton_Click(object sender, EventArgs e) {
      Content.Port = null;
    }
    protected virtual void portView_DragEnterOver(object sender, DragEventArgs e) {
      e.Effect = DragDropEffects.None;
      var data = e.Data.GetData(HeuristicLab.Common.Constants.DragDropDataFormat) as IMessagePort;

      if (!ReadOnly && (data != null)) {
        e.Effect = DragDropEffects.Link;
      }
    }
    protected virtual void portView_DragDrop(object sender, DragEventArgs e) {
      if (e.Effect != DragDropEffects.None) {
        var port = e.Data.GetData(HeuristicLab.Common.Constants.DragDropDataFormat) as IMessagePort;
        Content.Port = port;
      }
    }
  }
}
